@@ -10,7 +10,6 @@ import numexpr
 import xarray
 import bottleneck
 import numpy as np
-import xlsxwriter
 import xlrd
 import openpyxl
 import datetime
@@ -20,10 +19,13 @@ import warnings
 import PyPDF2
 from io import StringIO
 
-
 pd.set_option("mode.chained_assignment",None)
 pd.set_option("display.notebook_repr_html",True)
 pd.set_option("display.width",None)
+pd.set_option('display.expand_frame_repr', False)
+pd.set_option('display.max_rows', 500)
+pd.set_option('display.max_columns', 10)
+pd.set_option('display.width', 250)
 
 def getPDFText(path: str) -> str:
     text = ""
@@ -354,9 +356,9 @@ def getCharges(text: str, cnum: str):
     ch_Series = charges['Charges']
     noNumCode = ch_Series.str.slice(8)
     noNumCode = noNumCode.str.strip()
-    noDatesEither = noNumCode.str.replace("\d{2}/\d{2}/\d{4}",'',regex=True)
-    noWeirdColons = noDatesEither.str.replace("\:.+","",regex=True)
-    descSplit = noWeirdColons.str.split(".{3}-.{3}-.{3}",regex=True)
+    noDatesEither = noNumCode.str.replace("\d{2}/\d{2}/\d{4}",'', regex=True)
+    noWeirdColons = noDatesEither.str.replace("\:.+","", regex=True)
+    descSplit = noWeirdColons.str.split(".{3}-.{3}-.{3}", regex=True)
     descOne = descSplit.map(lambda x: x[0])
     descTwo = descSplit.map(lambda x: x[1])
 
@@ -392,7 +394,10 @@ def getCharges(text: str, cnum: str):
 
     descs['DoneWon'] = descs['One'].astype(str)
     descs['DoneWon'][descs['Winner']<0] = descs['Two'][descs['Winner']<0]
+    descs['DoneWon'] = descs['DoneWon'].str.replace("(©.*)","",regex=True)
+    descs['DoneWon'] = descs['DoneWon'].str.replace(":","")
     descs['DoneWon'] = descs['DoneWon'].str.strip()
+
     charges['Description'] = descs['DoneWon']
 
     charges['Category'] = charges['Category'].astype("category")
@@ -427,8 +432,20 @@ def getCharges(text: str, cnum: str):
 
     return [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct, charge_codes, conv_codes, allcharge, charges]
 
-#### CONFIGURATION METHOD - CALL ALAC.CONFIG() TO FEED CONF TO WRITE METHODS
-def config(input_path, tables_path=None, archive_path=None, text_path=None, tables="", print_log=True, verbose=True, warn=False, max_cases=0, force_overwrite=True, GUI_mode=False, drop_cols=True): 
+
+## CONFIGURATION METHODS - CALL ALAC.CONFIG() TO FEED CONF TO WRITE METHODS
+def checkPath(path: str):
+        head = os.path.split(path)[0]
+        tail = os.path.split(path)[1]
+        ext = os.path.splitext(path)[1]
+
+        if os.path.isdir(head):
+            GoodHead = True
+        if os.path.isfile(tail):
+            FileAlreadyExists = True
+
+
+def config(input_path, table_path=None, archive_path=None, text_path=None, tables="", print_log=True, verbose=True, warn=False, max_cases=0, force_overwrite=True, GUI_mode=False, drop_cols=True): 
 
     tab_ext = ""
     arc_ext = ""
@@ -444,6 +461,7 @@ def config(input_path, tables_path=None, archive_path=None, text_path=None, tabl
 ## CONFIG - INPUT
 
     ## FILE INPUT (.PDF, .TXT, .PKL.XZ)
+
     if os.path.isfile(input_path): 
         in_head = os.path.split(input_path)[0]
         in_tail = os.path.split(input_path)[1]
@@ -523,7 +541,7 @@ def config(input_path, tables_path=None, archive_path=None, text_path=None, tabl
                 try: # if exists at path, append
                     old_archive = pd.read_pickle(archive_path,compression="xz")
                     appendArchive = True
-                except KeyError: # 
+                except: 
                     raise Exception("Invalid archive output path!")
             else:
                 old_archive = None
@@ -532,13 +550,13 @@ def config(input_path, tables_path=None, archive_path=None, text_path=None, tabl
             raise Exception("Invalid file extension! Archives must export to .pkl.xz")
 
 ## CONFIG - TABLE OUT
-    if tables_path != None:
-        tab_head = os.path.split(tables_path)[0]
+    if table_path != None:
+        tab_head = os.path.split(table_path)[0]
         if os.path.exists(tab_head) is False:
             raise Exception(f"Invalid table output path!")
-        tab_tail = os.path.split(tables_path)[1]
+        tab_tail = os.path.split(table_path)[1]
         tab_ext = os.path.splitext(tab_tail)[1]
-        if os.path.isfile(tables_path):
+        if os.path.isfile(table_path):
             if force_overwrite:
                 if warn:
                     print("WARNING: FORCE OVERWRITE MODE IS ENABLED. EXISTING FILE AT TABLE OUTPUT PATH WILL BE OVERWRITTEN.")
@@ -554,29 +572,31 @@ def config(input_path, tables_path=None, archive_path=None, text_path=None, tabl
         else:
             raise Exception("Invalid table output file extension! Must write to .xls, .xlsx, .pkl.xz, .csv, .json, or .dta.")
 
-    if tables_path != None and archive_path != None and tables_path == archive_path:
+    if table_path != None and archive_path != None and table_path == archive_path:
         raise Exception("Cannot write tables and archive to same file!")
 
 ## CONFIG - LOG INPUT 
     if print_log and verbose:
-        if tables_path == None and archive_path == None:
+        if table_path == None and archive_path == None:
             if GUI_mode == False:
-                print(f"No output path provided. alac.parse...() functions will {'print to console and' if print_log else ''} return object.")
+                print(f"\nNo output path provided. alac.parse...() functions will {'print to console and' if print_log else ''} return object.")
             if GUI_mode == True:
                 raise Exception(f"No output path provided! Use alac libraries without guided interface to return object to python.")
         if content_length > max_cases:
-            print(f"\n{max_cases} of {content_length} total {'paths' if pathMode else 'cases'} loaded from input: {input_path}")
+            print(f"\n>>    INPUT:  {max_cases} of {content_length} total {'paths' if pathMode else 'cases'} loaded from input: {input_path}")
         if content_length <= max_cases:
             print(f"\n>>    INPUT:  {max_cases} {'paths' if pathMode else 'cases'} loaded from input: {input_path if pathMode else ''}")
-        if tables_path != None:
-            print(f">>    TABLES:  {'cases, charges, fees' if tables == '' else tables} to {tables_path}")
+        if table_path != None:
+            print(f">>    TABLES:  {'cases, charges, fees' if tables == '' else tables} to {table_path}")
         if archive_path != None:
             print(f">>    ARCHIVE:  {'cases, charges, fees' if tables == '' else tables} to {'existing archive at: ' if appendArchive else ''}{archive_path}\n\n")
+        print("\n")
+
 
 ## CONFIG OBJECT
     return pd.Series({
         'input_path': input_path,
-        'table_out': tables_path,
+        'table_out': table_path,
         'table_ext': tab_ext,
         'table': tables,
         'archive_out': archive_path,
@@ -592,6 +612,120 @@ def config(input_path, tables_path=None, archive_path=None, text_path=None, tabl
         'drop_cols': drop_cols
         })
 
+def checkPath(path: str):
+    PathType = ""
+    if os.path.isdir(path):
+        count = len(glob.glob(path + '**/*.pdf', recursive=True))
+        if count == 0:
+            PathType = "bad"
+            warnings.warn("No PDFs found in input path!")
+        if count > 0:
+            PathType = "pdf_directory"
+            return PathType
+    else:
+        head = os.path.split(path)[0]
+        tail = os.path.split(path)[1]
+        ext = os.path.splitext(path)[1]
+
+        if not os.path.isdir(head):
+            PathType = "bad"
+            warnings.warn("ERROR: Invalid output path!")
+            return PathType
+
+        if os.path.isfile(path):
+            if ext == ".xz":
+                test = pd.read_pickle(path,compression="xz")
+                if "AllPagesText" in test.columns:
+                    PathType = "existing_archive"
+                    return PathType
+                else:
+                    PathType = "overwrite_archive"
+                    warnings.warn("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
+                    return PathType
+            elif ext == ".xls" or ext == ".xlsx":
+                PathType = "overwrite_all_tables"
+                return PathType
+            elif ext == ".csv" or ext == ".json" or ext == ".dta" or ext == ".txt":
+                PathType = "overwrite_table"
+                return PathType
+            else:
+                PathType = "bad"
+                warnings.warn("Output file extension not supported!")
+                warnings.warn("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
+                return PathType
+        else:
+            if ext == ".xls" or ext == ".xlsx":
+                PathType = "all_tables"
+                return PathType
+            elif ext == ".xz":
+                PathType = "archive"
+                return PathType
+            elif ext == ".csv" or ext == ".json" or ext == ".dta" or ext == ".txt":
+                PathType = "table"
+                return PathType
+            else:
+                PathType = "bad"
+                warnings.warn("Output file extension not supported!")
+                return PathType
+    return PathType
+
+def write(conf, outputs):
+    max_cases = conf['count']
+    path_out = conf['table_out']
+    print_log = conf['log']
+    warn = conf['warn']
+    try:
+        out_ext = os.path.splitext(path_out)[1]
+    except TypeError:
+        out_ext = ".xlsx"
+        print("Warning: default export to .xlsx. Investigate in debug!!") ### DEBUG MARKER
+
+    if out_ext == ".xls":
+        with pd.ExcelWriter(path_out) as writer:
+            outputs.to_excel(writer, sheet_name="output-table")
+    if out_ext == ".xlsx":
+        try:
+            with pd.ExcelWriter(path_out) as writer:
+                outputs.to_excel(writer, sheet_name="output-table", engine="xlsxwriter")
+        except ValueError:
+            try:
+                with pd.ExcelWriter(path_out[0:-1]) as writer:
+                    outputs.to_excel(writer, sheet_name="output-table")
+            except ValueError:
+                outputs.to_csv(path_out,escapechar='\\')
+                print("Exported to CSV due to XLSX engine failure")
+    elif out_ext == ".pkl":
+        outputs.to_pickle(path_out+".xz",compression="xz")
+    elif out_ext == ".xz":
+        outputs.to_pickle(path_out,compression="xz")
+    elif out_ext == ".json":
+        outputs.to_json(path_out)
+    elif out_ext == ".csv":
+        outputs.to_csv(path_out,escapechar='\\')
+    elif out_ext == ".txt":
+        outputs.to_string(path_out)
+    elif out_ext == ".dta":
+        outputs.to_stata(path_out)
+    else:
+        if warn:
+            print("Warning: Failed to export!")
+    return outputs 
+
+
+def parseTables(config, tables=""): # aim to remove
+        if tables == "all" or tables == "all_cases" or tables == "":
+            a = alac.parseCases(config)
+        if tables == "cases":
+            a = alac.parseCaseInfo(config)
+        if tables == "fees":
+            a = alac.parseFees(config)
+        if tables == "charges":
+            a = alac.parseCharges(config)
+        if tables == "disposition":
+            a = alac.parseCharges(config)
+        if tables == "filing":
+            a = alac.parseCharges(config)
+        return a
 
 def writeArchive(conf): 
     path_in = conf['input_path']
@@ -620,36 +754,7 @@ def writeArchive(conf):
 
     outputs.fillna('',inplace=True)
 
-    if bool(path_out):
-        if out_ext == ".xls":
-            with pd.ExcelWriter(path_out) as writer:
-                outputs.to_excel(writer, sheet_name="output-table")
-        if out_ext == ".xlsx":
-            try:
-                with pd.ExcelWriter(path_out) as writer:
-                    outputs.to_excel(writer, sheet_name="output-table", engine="xlsxwriter")
-            except ValueError:
-                try:
-                    with pd.ExcelWriter(path_out[0:-1]) as writer:
-                        outputs.to_excel(writer, sheet_name="output-table")
-                except ValueError:
-                    outputs.to_csv(path_out,escapechar='\\')
-                    print("Exported to CSV due to XLSX engine failure")
-        if out_ext == ".pkl":
-            outputs.to_pickle(path_out+".xz",compression="xz")
-        if out_ext == ".xz":
-            outputs.to_pickle(path_out,compression="xz")
-        if out_ext == ".json":
-            outputs.to_json(path_out)
-        if out_ext == ".csv":
-            outputs.to_csv(path_out,escapechar='\\')
-        if out_ext == ".txt":
-            outputs.to_string(path_out)
-        if out_ext == ".dta":
-            outputs.to_stata(path_out)
-    else:
-        if print_log:
-            log_console(conf, f"(Batch {i}/{math.ceil(max_cases /1000)})", outputs.to_string())
+    write(conf, outputs)
     log_complete(conf, start_time)
     return outputs
 
@@ -688,10 +793,7 @@ def parseFees(conf):
         b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
         b['FeeOutputs'] = b.index.map(lambda x: getFeeSheet(b.loc[x].AllPagesText, b.loc[x].CaseNumber))
 
-        fees['AmtDue'] = fees['AmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
-        fees['AmtPaid'] = fees['AmtPaid'].map(lambda x: pd.to_numeric(x,'coerce'))
-        fees['Balance'] = fees['Balance'].map(lambda x: pd.to_numeric(x,'coerce'))
-        fees['AmtHold'] = fees['AmtHold'].map(lambda x: pd.to_numeric(x,'coerce'))
+
 
         feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
         feesheet = feesheet.dropna() # drop empty 
@@ -700,41 +802,13 @@ def parseFees(conf):
         feesheet = pd.concat(feesheet,axis=0,ignore_index=True) # add all dfs in batch -> df
         fees = fees.append(feesheet, ignore_index=True) 
         fees = fees[['CaseNumber', 'Total', 'FeeStatus', 'AdminFee', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']]
-
         fees.fillna('',inplace=True)
-
+        fees['AmtDue'] = fees['AmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
+        fees['AmtPaid'] = fees['AmtPaid'].map(lambda x: pd.to_numeric(x,'coerce'))
+        fees['Balance'] = fees['Balance'].map(lambda x: pd.to_numeric(x,'coerce'))
+        fees['AmtHold'] = fees['AmtHold'].map(lambda x: pd.to_numeric(x,'coerce'))
         # write 
-        if out_ext == ".xls":
-            with pd.ExcelWriter(path_out) as writer:
-                fees.to_excel(writer, sheet_name="fees")
-        if out_ext == ".xlsx":
-            try:
-                with pd.ExcelWriter(path_out) as writer:
-                    fees.to_excel(writer, sheet_name="fees", engine="xlsxwriter")
-            except ValueError:
-                try:
-                    with pd.ExcelWriter(path_out[0:-1]) as writer:
-                        fees.to_excel(writer, sheet_name="fees")
-                except ValueError:
-                    outputs.to_csv(path_out,escapechar='\\')
-                    print("Exported to CSV due to XLSX engine failure")
-        elif out_ext == ".pkl":
-            fees.to_pickle(path_out+".xz",compression="xz")
-        elif out_ext == ".xz":
-            fees.to_pickle(path_out,compression="xz")
-        elif out_ext == ".json":
-            fees.to_json(path_out)
-        elif out_ext == ".csv":
-            fees.to_csv(path_out,escapechar='\\')
-        elif out_ext == ".md":
-            fees.to_markdown(path_out)
-        elif out_ext == ".txt":
-            fees.to_string(path_out)
-        elif out_ext == ".dta":
-            fees.to_stata(path_out)
-        else:
-            if print_log:
-                log_console(conf, fees.to_string(), f"\n(Batch {i}/{math.ceil(max_cases/1000)})")
+        write(conf, fees)
         
     if print_log == True:
         log_complete(conf, start_time)
@@ -763,7 +837,7 @@ def parseCharges(conf):
 
     start_time = time.time()
     outputs = pd.DataFrame()
-    charges = pd.DataFrame({'CaseNumber': '', 'Num': '', 'Code': '', 'Felony': '', 'Conviction': '', 'CERV': '', 'Pardon': '', 'Permanent': '', 'Disposition': '', 'CourtActionDate': '', 'CourtAction': '', 'Cite': '', 'TypeDescription': '', 'Category': '', 'Description': ''},index=[0]) 
+    charges = pd.DataFrame()
     for i, c in enumerate(batches):
         exptime = time.time()
         b = pd.DataFrame()
@@ -780,8 +854,6 @@ def parseCharges(conf):
         
         chargetabs = b['ChargesOutputs'].map(lambda x: x[17])
         chargetabs = chargetabs.dropna()
-
-        charges = charges.dropna()
         chargetabs = chargetabs.tolist()
         chargetabs = pd.concat(chargetabs,axis=0,ignore_index=True)
         charges = charges.append(chargetabs,ignore_index=True)
@@ -790,60 +862,21 @@ def parseCharges(conf):
         if table == "filing":
             is_disp = charges['Disposition']
             is_filing = is_disp.map(lambda x: False if x == True else True)
-            charges = charges[is_disp]
+            charges = charges[is_filing]
 
         if table == "disposition":
-            is_disp = charges['Disposition']
+            is_disp = charges.Disposition.map(lambda x: True if x == True else False)
             charges = charges[is_disp]
 
-        charges = charges[['CaseNumber', 'Num', 'Code', 'Description', 'Cite', 'CourtAction', 'CourtActionDate', 'Category', 'TypeDescription', 'Disposition', 'Permanent', 'Pardon', 'CERV','Conviction']]
 
-        # write 
-        if out_ext == ".xls":
-            try:
-                with pd.ExcelWriter(path_out) as writer:
-                    charges.to_excel(writer, sheet_name="charges", engine="xlsxwriter")
-            except ValueError:
-                try:
-                    with pd.ExcelWriter(path_out) as writer:
-                        charges.to_excel(writer, sheet_name="charges")
-                except ValueError:
-                    charges.to_csv(path_out,escapechar='\\')
-                    log_console(conf, charges, f"\n(Batch {i}) ERROR: Exported to CSV due to XLS engine failure")
-        if out_ext == ".xlsx":
-            try:
-                with pd.ExcelWriter(path_out) as writer:
-                    charges.to_excel(writer, sheet_name="charges", engine="xlsxwriter")
-            except ValueError:
-                try:
-                    with pd.ExcelWriter(path_out) as writer:
-                        charges.to_excel(writer, sheet_name="charges")
-                except ValueError:
-                    charges.to_csv(path_out,escapechar='\\')
-                    log_console(conf, charges.to_string(), "(Batch {i}) ERROR: Exported to CSV due to XLSX engine failure!")
-        elif out_ext == ".pkl":
-            charges.to_pickle(path_out+".xz",compression="xz")
-        elif out_ext == ".xz":
-            charges.to_pickle(path_out,compression="xz")
-        elif out_ext == ".json":
-            charges.to_json(path_out)
-        elif out_ext == ".csv":
-            charges.to_csv(path_out,escapechar='\\')
-        elif out_ext == ".md":
-            charges.to_markdown(path_out)
-        elif out_ext == ".txt":
-            charges.to_string(path_out)
-        elif out_ext == ".dta":
-            charges.to_stata(path_out)
-        else:
-            if print_log:
-                log_console(conf, "(Batch {i}) ", charges.to_string())
+        write(conf, charges)
 
     if print_log == True:
         log_complete(conf, start_time)
+
     return charges
 
-def parseTables(conf):
+def parseCases(conf):
     path_in = conf['input_path']
     path_out = conf['table_out']
     archive_out = conf['archive_out']
@@ -917,11 +950,6 @@ def parseTables(conf):
         b['FeeCodes'] = b['FeeOutputs'].map(lambda x: x[4])
         b['FeeSheet'] = b['FeeOutputs'].map(lambda x: x[5])
 
-        fees['AmtDue'] = fees['AmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
-        fees['AmtPaid'] = fees['AmtPaid'].map(lambda x: pd.to_numeric(x,'coerce'))
-        fees['Balance'] = fees['Balance'].map(lambda x: pd.to_numeric(x,'coerce'))
-        fees['AmtHold'] = fees['AmtHold'].map(lambda x: pd.to_numeric(x,'coerce'))
-
         feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
         feesheet = feesheet.dropna() 
         fees = fees.dropna()
@@ -954,14 +982,18 @@ def parseTables(conf):
             pass
 
         if print_log == True:
-            log_console(conf, "(Batch {i}) ", charges)
-
+            log_console(conf, f"(Batch {i+1}) ", charges)
+        
+        fees['AmtDue'] = fees['AmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
+        fees['AmtPaid'] = fees['AmtPaid'].map(lambda x: pd.to_numeric(x,'coerce'))
+        fees['Balance'] = fees['Balance'].map(lambda x: pd.to_numeric(x,'coerce'))
+        fees['AmtHold'] = fees['AmtHold'].map(lambda x: pd.to_numeric(x,'coerce'))
 
         b['ChargesTable'] = b['ChargesOutputs'].map(lambda x: x[-1])
-        b['TotalD999'] = b['TotalD999'].map(lambda x: pd.to_numeric(x,'ignore'))
-        b['Phone'] =  b['Phone'].map(lambda x: pd.to_numeric(x,'ignore'))
-        b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x,'ignore'))
-        b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x,'ignore'))
+        b['TotalD999'] = b['TotalD999'].map(lambda x: pd.to_numeric(x,'coerce'))
+        b['Phone'] =  b['Phone'].map(lambda x: pd.to_numeric(x,'coerce'))
+        b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
+        b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x,'coerce'))
 
         if bool(archive_out) and len(arc_ext) > 2:
             timestamp = start_time
@@ -975,7 +1007,6 @@ def parseTables(conf):
             arch.dropna(inplace=True)
             arch.to_pickle(archive_out,compression="xz")
 
-       #  b = [['CaseNumber','Name','Alias','DOB','Race','Sex','Address','Phone','TotalAmtDue','TotalBalance','DispositionCharges','Conviction','FeeCodes','FeeCodesOwed','CERVConvictions','CERVConvictionCount','PardonConvictions','PardonConvictionCount','PermanentConvictions','PermanentConvictionCount']]
         b.drop(columns=['AllPagesText','CaseInfoOutputs','ChargesOutputs','FeeOutputs','TotalD999','ChargesTable','FeeSheet'],inplace=True)
         
         b.fillna('',inplace=True)
@@ -1009,7 +1040,7 @@ def parseTables(conf):
                     charges.to_excel(writer, sheet_name="charges")
             except ImportError:
                 try:
-                    with pd.ExcelWriter(path_out.slice[0:-1]) as writer:
+                    with pd.ExcelWriter(path_out) as writer:
                         cases.to_excel(writer, sheet_name="cases")
                         fees.to_excel(writer, sheet_name="fees")
                         charges.to_excel(writer, sheet_name="charges")
@@ -1018,7 +1049,7 @@ def parseTables(conf):
                         cases.to_csv(path_out + ".csv",escapechar='\\')
                         fees.to_csv(path_out + ".csv",escapechar='\\')
                         charges.to_csv(path_out + ".csv",escapechar='\\')
-                        log_console(conf, "(Batch {i}) - WARNING: Exported to CSV due to XLSX engine failure")
+                        log_console(conf, f"(Batch {i+1}) - WARNING: Exported to CSV due to XLSX engine failure")
                     except (ImportError, FileNotFoundError):
                         pass
         elif out_ext == ".pkl":
@@ -1036,11 +1067,81 @@ def parseTables(conf):
         elif out_ext == ".dta":
             b.to_stata(path_out)
         else:
-            log_console(conf, "(Batch {i}) ", b, charges, fees)
+            log_console(conf, f"(Batch {i+1}) ", b, charges, fees)
         if print_log == True:
             log_complete(conf, start_time)
     return [cases, fees, charges]
 
+def parseCaseInfo(conf):
+    path_in = conf['input_path']
+    path_out = conf['table_out']
+    archive_out = conf['archive_out']
+    max_cases = conf['count']
+    out_ext = conf['table_ext']
+    print_log = conf['log']
+    warn = conf['warn']
+    queue = conf['queue']
+    from_archive = False if conf['path_mode'] else True
+    start_time = time.time()
+    arc_ext = conf['archive_ext']
+    
+    cases = pd.DataFrame()
+
+    if not from_archive:
+        if max_cases > 1000:
+            batches = np.array_split(queue, math.ceil(max_cases / 1000))
+            batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+        else:
+            batches = np.array_split(queue, 3)
+            batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+    else:
+        batches = np.array_split(queue, 2)
+        batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+
+    if warn == False:
+        warnings.filterwarnings("ignore")
+
+    for i, c in enumerate(batches):
+
+        b = pd.DataFrame()
+        if from_archive == True:
+            b['AllPagesText'] = c
+        else:
+            b['AllPagesText'] = pd.Series(c).map(lambda x: getPDFText(x))
+
+        b['CaseInfoOutputs'] = b['AllPagesText'].map(lambda x: getCaseInfo(x))
+        b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
+        b['Name'] = b['CaseInfoOutputs'].map(lambda x: x[1])
+        b['Alias'] = b['CaseInfoOutputs'].map(lambda x: x[2])
+        b['DOB'] = b['CaseInfoOutputs'].map(lambda x: x[3])
+        b['Race'] = b['CaseInfoOutputs'].map(lambda x: x[4])
+        b['Sex'] = b['CaseInfoOutputs'].map(lambda x: x[5])
+        b['Address'] = b['CaseInfoOutputs'].map(lambda x: x[6])
+        b['Phone'] = b['CaseInfoOutputs'].map(lambda x: x[7])
+        b['Totals'] = b['AllPagesText'].map(lambda x: getFeeTotals(x))
+        b['TotalAmtDue'] = b['Totals'].map(lambda x: x[1])
+        b['TotalAmtPaid'] = b['Totals'].map(lambda x: x[2])
+        b['TotalBalance'] = b['Totals'].map(lambda x: x[3])
+        b['TotalAmtHold'] = b['Totals'].map(lambda x: x[4])
+
+        if print_log == True:
+            log_console(conf, b, f"\n(Batch {i+1})\n")
+        
+        b['Phone'] =  b['Phone'].map(lambda x: pd.to_numeric(x,'coerce'))
+        b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
+        b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x,'coerce'))
+
+        b.drop(columns=['AllPagesText','CaseInfoOutputs','Totals'],inplace=True)
+        
+        b.fillna('',inplace=True)
+        newcases = [cases, b]
+
+        cases = cases.append(newcases, ignore_index=True)
+
+        # write 
+        write(conf, cases)
+    return cases
+
 def parse(conf, method, status=''):
     path_in = conf['input_path']
     path_out = conf['table_out']
@@ -1077,37 +1178,7 @@ def parse(conf, method, status=''):
 
         customoutputs = allpagestext.map(lambda x: method(x))
         alloutputs = alloutputs.append(customoutputs)
-        
-        if out_ext == ".xls":
-            with pd.ExcelWriter(path_out) as writer:
-                alloutputs.to_excel(writer, sheet_name="output-table")
-        if out_ext == ".xlsx":
-            try:
-                with pd.ExcelWriter(path_out) as writer:
-                    alloutputs.to_excel(writer, sheet_name="output-table", engine="xlsxwriter")
-            except ValueError:
-                try:
-                    with pd.ExcelWriter(path_out[0:-1]) as writer:
-                        alloutputs.to_excel(writer, sheet_name="output-table")
-                except ValueError:
-                    alloutputs.to_csv(path_out,escapechar='\\')
-                    log_console(conf, f"(Batch {i}) - WARNING: Exported to CSV due to XLSX engine failure")
-        elif out_ext == ".pkl":
-            alloutputs.to_pickle(path_out+".xz",compression="xz")
-        elif out_ext == ".xz":
-            alloutputs.to_pickle(path_out,compression="xz")
-        elif out_ext == ".json":
-            alloutputs.to_json(path_out)
-        elif out_ext == ".csv":
-            alloutputs.to_csv(path_out,escapechar='\\')
-        elif out_ext == ".md":
-            alloutputs.to_markdown(path_out)
-        elif out_ext == ".txt":
-            alloutputs.to_string(path_out)
-        elif out_ext == ".dta":
-            alloutputs.to_stata(path_out)
-        else:
-            log_console(conf, alloutputs.to_string())
+        write(conf, alloutputs)
 
     if print_log == True:
         log_complete(conf, start_time)
@@ -1127,14 +1198,16 @@ def log_complete(conf, start_time):
     if print_log:
         print(f'''
 
-        INPUT: {path_in} 
-        OUTPUT: {path_out} 
-        ARCHIVE: {arc_out}
+>>  ALACORDER PROGRESS:
 
-        Processing {max_cases} cases...
-        Last batch completed in {elapsed:.2f} seconds ({cases_per_sec:.2f}cases/sec)
+    >>    INPUT: {path_in} 
+    >>    OUTPUT: {path_out} 
+    >>    ARCHIVE: {arc_out}
 
-        \n''') 
+    >>    Processing {max_cases} cases...
+    >>    Last batch completed in {elapsed:.2f} seconds ({cases_per_sec:.2f}cases/sec)
+        
+        ''') 
 
 def log_console(conf, *msg):
     path_in = conf['input_path']
